==> lxqt-panel-2.3.0.tar.xz: lxqt-panel-2.3.0/plugin-customcommand/translations/customcommand_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation>Värvi muutmiseks klõpsi</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation>Vali värv</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Kohandatud käskude seadistamine</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Liides</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="303"/>
        <source>Use icon from theme or browse file</source>
        <translation>Kasuta teemale vastavat ikooni või vali oma</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Käivita „bash -c“ abil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="107"/>
        <source>Select Font</source>
        <translation>Vali font</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="280"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="68"/>
        <source>Command</source>
        <translation>Käsk</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="166"/>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="78"/>
        <source> px</source>
        <translation> pikslit</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="263"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="266"/>
        <source>Use %1 to display command output</source>
        <translation>Käsu väljundi kuvamiseks kasuta %1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="173"/>
        <source>Icon</source>
        <translation>Ikoon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="293"/>
        <source>Browse</source>
        <translation>Sirvi</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="159"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Kui paneel asub püstloodis, siis pööra automaatselt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="43"/>
        <source>Output format:</source>
        <translation>Väljundvorming:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="50"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
        <source>echo Configure...</source>
        <translation>Seadista echo...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="142"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="341"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="358"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="375"/>
        <source>Command to run</source>
        <translation>Käivitatav käsk</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="149"/>
        <source>Max Width</source>
        <translation>Suurim laius</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="225"/>
        <source>Repeat command after:</source>
        <translation>Käsu kordamise aeg:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="117"/>
        <source>Text Color</source>
        <translation>Teksti värv</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Reset</source>
        <translation>Lähtesta</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source> second(s)</source>
        <translation> sekund(it)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="273"/>
        <source>Tooltip</source>
        <translation>Kohtspikker</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="310"/>
        <source>Continuous output (processed line by line)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <source>Mouse Commands</source>
        <translation>Hiirekäsud</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="331"/>
        <source>Click</source>
        <translation>Klõpsimine</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="348"/>
        <source>Wheel Up</source>
        <translation>Ratta viibe üles</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="365"/>
        <source>Wheel Down</source>
        <translation>Ratta viibe alla</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="37"/>
        <source>command outputs plain text to be used as text of the button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="38"/>
        <source>command outputs icon in form of:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="39"/>
        <source>theme name</source>
        <translation>kujunduse nimi</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="40"/>
        <source>name of icon resolved to image based on XDG spec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="41"/>
        <source>image file path</source>
        <translation>pildifaili asukoht</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="42"/>
        <source>image data stream</source>
        <translation>pildi andmevoog</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="43"/>
        <source>plain image stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="44"/>
        <source>base64 encoded image data stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="45"/>
        <source>as above but base64 encoded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="46"/>
        <source>command outputs structured variables to be used for button visualization in form of:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="47"/>
        <source>name1:base64value1 name2:base64value2  ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="48"/>
        <source>Handled names are:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="49"/>
        <source>string to be used as text of the button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="50"/>
        <source>icon to be shown in the button, in the same form as explained before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="51"/>
        <source>string to be used as tooltip of the button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="52"/>
        <source>All values should be encoded in base64</source>
        <translation>Kõik väärtused peaks olema kodeeritud base64-na</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="53"/>
        <source>Example of script generating structured output:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="54"/>
        <source>My Text</source>
        <translation>Minu tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="55"/>
        <source>my_image</source>
        <translation>minu_pilt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="56"/>
        <source>My Tooltip</source>
        <translation>Minu kohtspikker</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="63"/>
        <source>Text only</source>
        <translation>Ainult tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="64"/>
        <source>Icon only</source>
        <translation>Ainult ikoon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="65"/>
        <source>Structured</source>
        <translation>Struktureeritud</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="268"/>
        <source>Select Icon File</source>
        <translation>Vali ikooni fail</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="268"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Pildid (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.3.1.tar.xz: lxqt-panel-2.3.1/plugin-customcommand/translations/customcommand_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation>Värvi muutmiseks klõpsi</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation>Vali värv</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Kohandatud käskude seadistamine</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Liides</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="303"/>
        <source>Use icon from theme or browse file</source>
        <translation>Kasuta teemale vastavat ikooni või vali oma</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Käivita „bash -c“ abil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="107"/>
        <source>Select Font</source>
        <translation>Vali font</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="280"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="68"/>
        <source>Command</source>
        <translation>Käsk</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="166"/>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="78"/>
        <source> px</source>
        <translation> pikslit</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="263"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="266"/>
        <source>Use %1 to display command output</source>
        <translation>Käsu väljundi kuvamiseks kasuta %1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="173"/>
        <source>Icon</source>
        <translation>Ikoon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="293"/>
        <source>Browse</source>
        <translation>Sirvi</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="159"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Kui paneel asub püstloodis, siis pööra automaatselt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="43"/>
        <source>Output format:</source>
        <translation>Väljundvorming:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="50"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
        <source>echo Configure...</source>
        <translation>Seadista echo...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="142"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="341"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="358"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="375"/>
        <source>Command to run</source>
        <translation>Käivitatav käsk</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="149"/>
        <source>Max Width</source>
        <translation>Suurim laius</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="225"/>
        <source>Repeat command after:</source>
        <translation>Käsu kordamise aeg:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="117"/>
        <source>Text Color</source>
        <translation>Teksti värv</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Reset</source>
        <translation>Lähtesta</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source> second(s)</source>
        <translation> sekund(it)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="273"/>
        <source>Tooltip</source>
        <translation>Kohtspikker</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="310"/>
        <source>Continuous output (processed line by line)</source>
        <translation>Pidev väljund (töödeldud ridahaaval)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <source>Mouse Commands</source>
        <translation>Hiirekäsud</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="331"/>
        <source>Click</source>
        <translation>Klõpsimine</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="348"/>
        <source>Wheel Up</source>
        <translation>Ratta viibe üles</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="365"/>
        <source>Wheel Down</source>
        <translation>Ratta viibe alla</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="37"/>
        <source>command outputs plain text to be used as text of the button</source>
        <translation>käsu väljundiks on tavatekst, mida saab kasutada nupu tekstina</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="38"/>
        <source>command outputs icon in form of:</source>
        <translation>käsu väljundiks on ikoon järgmises vormingus:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="39"/>
        <source>theme name</source>
        <translation>kujunduse nimi</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="40"/>
        <source>name of icon resolved to image based on XDG spec</source>
        <translation>ikooni nimi, mis järgib pildi nime vastavalt XDG spetsifikatsioonile</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="41"/>
        <source>image file path</source>
        <translation>pildifaili asukoht</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="42"/>
        <source>image data stream</source>
        <translation>pildi andmevoog</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="43"/>
        <source>plain image stream</source>
        <translation>pildi tavaline sisuvoog</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="44"/>
        <source>base64 encoded image data stream</source>
        <translation>base64 kodeeringus pildi sisuvoog</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="45"/>
        <source>as above but base64 encoded</source>
        <translation>sama, kui ülal, aga base64 kodeeringus</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="46"/>
        <source>command outputs structured variables to be used for button visualization in form of:</source>
        <translation>käsi väljundiks on struktureeritud muutujad, mida saab kasutada nupu visualiseerimiseks järgmises vormingus:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="47"/>
        <source>name1:base64value1 name2:base64value2  ...</source>
        <translation>nimi1:base64väärtus1 nimi2:base64väärtus2  ...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="48"/>
        <source>Handled names are:</source>
        <translation>Käsitletavad nimed on:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="49"/>
        <source>string to be used as text of the button</source>
        <translation>sõne, mida kasutatakse nupu tekstina</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="50"/>
        <source>icon to be shown in the button, in the same form as explained before</source>
        <translation>ikoon, mida kuvatakse nupul, kasutusel on eespool kirjeldatud vorming</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="51"/>
        <source>string to be used as tooltip of the button</source>
        <translation>sõne, mida kasutatakse nupu kohtvihjena</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="52"/>
        <source>All values should be encoded in base64</source>
        <translation>Kõik väärtused peaks olema kodeeritud base64-na</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="53"/>
        <source>Example of script generating structured output:</source>
        <translation>Skripti näidis, mis lood struktureeritud sisu:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="54"/>
        <source>My Text</source>
        <translation>Minu tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="55"/>
        <source>my_image</source>
        <translation>minu_pilt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="56"/>
        <source>My Tooltip</source>
        <translation>Minu kohtspikker</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="63"/>
        <source>Text only</source>
        <translation>Ainult tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="64"/>
        <source>Icon only</source>
        <translation>Ainult ikoon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="65"/>
        <source>Structured</source>
        <translation>Struktureeritud</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="268"/>
        <source>Select Icon File</source>
        <translation>Vali ikooni fail</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="268"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Pildid (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
